import React, { useEffect, useState } from "react";
import { getAddresses } from "./service";
import './autocomplete.css'
import TextField from "@mui/material/TextField";
import Autocomplete from "@mui/material/Autocomplete";
import CircularProgress from "@mui/material/CircularProgress";

export const ReactBatchAutocomplete = ({
  placeholder = "Enter your address",
  notFoundText = "Not found data",
  debounce = 700,
  apiKey,
  domainServer,
  handleError,
  suggestionList,
  onSelect,
  recentSearch
}) => {
  const [search, setSearch] = useState("");
  const [searchQuery, setSearchQuery] = useState("");
  const [open, setOpen] = useState(false);
  const [options, setOptions] = useState([]);
  const [recentSearchOption, setRecentSearchOption] = useState([]);
  const [loading, setLoading] = useState(false);
  const [renderRecentSearch, setRenderRecentSearch] = useState(true)
  
  useEffect(() => {
    search.length > 0 && setRenderRecentSearch(false)
    const timeout = setTimeout(() => {
      setSearchQuery(search);
    }, debounce);

    return () => {
      clearTimeout(timeout);
    };
  }, [search]);
  useEffect(async () => {
    if (searchQuery?.trim().length > 2 && options?.filter((item) => item.name === searchQuery)?.length === 0) {
      try {
        setLoading(true);
        let data = await getAddresses(apiKey, domainServer, searchQuery);
        if (data?.status?.code !== 200) {
          handleError?.(data?.status);
        } else {
          setOptions(data?.result?.suggestions);
          suggestionList?.(data?.result?.suggestions);
          setOpen(true);
        }
        setLoading(false);
      } catch (e) {
        handleError?.(e);
        setLoading(false);
      }
    }
  }, [searchQuery]);

  useEffect(() => {
    if (recentSearch) {
      setRecentSearchOption(recentSearch)
    }
  }, [recentSearch])
  
  return (
    <div className="autocomplete-wrapper">
    <Autocomplete
      disablePortal
      className="custom-autocomplete"
      open={open}
      onOpen={() => {
        search.length > 2 && options.length > 0 && setOpen(true);
      }}
      groupBy={() => renderRecentSearch ? 'Recent Searches' : ''}
      onClose={() => {
       setOpen(false);
      }}
      renderGroup={(value) => (renderRecentSearch ?
        <div className="recent-wrapper" key={value.group}>
          <div className="recent-title">
          <div className="recent-img" />
          <h6>{value.group}</h6>
          </div>
          {value.children}
        </div> : value.children
      )}
      onInputChange={(event, value) => {
        options.length === 0 && setOpen(false)
        if (!value && !recentSearch)
        {
          setOpen(false)
          setOptions([])
        }
        setSearch((prevValue) => {
          if (prevValue?.length > value.length && !value && recentSearch) {
            setRenderRecentSearch(true)
            setOpen(true)
            setOptions([])
          }
          return value
        });
      }}
      getOptionLabel={(option) => option.name ?? option.key}
      onChange={(event, data) => !renderRecentSearch && onSelect?.(data)}
      inputValue={search}
      options={renderRecentSearch ? recentSearchOption : options}
      noOptionsText={notFoundText}
      clearOnBlur={false}
      filterOptions={(options) => options}
      renderInput={(params) => (
        <TextField
          {...params}
          hiddenLabel
          placeholder={placeholder}
          id="filled-hidden-label-normal"
          onFocus={() => recentSearch && renderRecentSearch && setOpen(true)}
          InputProps={{
            ...params.InputProps,
            endAdornment: (
              <>
                {loading ? (
                  <CircularProgress className="spinner" size={20} />
                ) : null}
                {params.InputProps.endAdornment}
              </>
            ),
          }}
        />
      )}
      renderOption={(props, option) => {
        return renderRecentSearch ? (
            <div {...props}>
            <div className="auto-wrapper-recent">
            
              <div className="text-content">
                {option.name}
              </div>
              <div className="img-wrap-recent" />
            </div>
          </div>
          ) : (
          <div {...props}>
            <div className="auto-wrapper">
              <div className="img-wrap" />
              <div className="text-content">
                <strong>{option?.name?.substr(0, search?.trim()?.length)}</strong>
                {option?.name?.substr(search?.trim()?.length)}
              </div>
            </div>
          </div>
        );
      }}
    />
    </div>
  );
};